CheckBoxNG
==========

:term:`CheckBoxNG` is a hardware testing tool useful for certifying laptops,
desktops and servers with Ubuntu. It is a new version of :term:`CheckBox` that
is built directly on top of :term:`PlainBox`

CheckBoxNG *replaces* CheckBox, where applicable. 

Installation
============

CheckBoxNG is pre-installed on Ubuntu 14.04. It is also available in Debian (as
checkbox-ng) Testing.
